pub struct Transcript {
pub biotype: Option<Vec<BioType>>,
pub gene_name: Option<String>,
pub gene_version: String,
pub genome_builds: IndexMap<String, GenomeAlignment>,
pub hgnc: Option<String>,
pub id: String,
pub partial: Option<u8>,
pub protein: Option<String>,
pub start_codon: Option<i32>,
pub stop_codon: Option<i32>,
}Fields
biotype: Option<Vec<BioType>>Transcript biotype, e.g., vec![BioType::ProteinCoding] for BRCA1.
gene_name: Option<String>Gene name, e.g., "BRCA1" for BRCA1.
gene_version: StringGene version, NCBI gene ID for NCBI, e.g., "672" for BRCA1, ENSEMBL gene id, e.g.,
"ENSG00000012048" for BRCA1.
genome_builds: IndexMap<String, GenomeAlignment>Alignments to the different genome builds.
hgnc: Option<String>HGNC identifier, e.g. "1100" for BRCA1 which is HGNC:1100.
id: StringIdentifier of the transcript, same as key in transcripts, e.g., "NM_007294.3" for BRCA1.
partial: Option<u8>When the transcript does not match the primary assembly ("NC_") perfectly / the assembly itself is wrong/partial
protein: Option<String>Identifier of corresponding protein, e.g., "NP_009225.1" for "NM_007294.3" of BRCA1.
start_codon: Option<i32>0-based position of codon of transcript, e.g., 232 for "NM_007294.3" of BRCA1.
stop_codon: Option<i32>End position of stop codon of transcript, e.g., 5824 for "NM_007294.3" of BRCA1.